@@ -23,6 +23,7 @@ class Account:
         """Get or deploy an Account contract for the given private key."""
         try:
             self.signer = Signer(int(os.environ[signer]))
+            self.alias = signer
             self.network = network
         except KeyError:
             logging.error(
@@ -55,7 +56,9 @@ class Account:
             overriding_path,
         )
 
-        accounts.register(self.signer.public_key, address, index, self.network)
+        accounts.register(
+            self.signer.public_key, address, index, self.alias, self.network
+        )
 
         return address, index
 
@@ -66,7 +69,7 @@ class Account:
 
         if nonce is None:
             nonce = int(
-                call_or_invoke(self.address, "call", "get_nonce", [], self.network)
+                call_or_invoke(self.address, "call", "get_nonce", [], self.network)[0]
             )
 
         if max_fee is None:
@@ -80,11 +83,11 @@ class Account:
         )
 
         params = []
-        params.append(str(len(call_array)))
-        params.extend([str(elem) for sublist in call_array for elem in sublist])
-        params.append(str(len(calldata)))
-        params.extend([str(param) for param in calldata])
-        params.append(str(nonce))
+        params.append(len(call_array))
+        params.extend(*call_array)
+        params.append(len(calldata))
+        params.extend(calldata)
+        params.append(nonce)
 
         return call_or_invoke(
             contract=self.address,
