@@ -4,7 +4,7 @@ import os
 import subprocess
 
 from nile import deployments
-from nile.common import GATEWAYS
+from nile.common import GATEWAYS, prepare_params
 
 
 def call_or_invoke(
@@ -32,6 +32,8 @@ def call_or_invoke(
         gateway_prefix = "feeder_gateway" if type == "call" else "gateway"
         command.append(f"--{gateway_prefix}_url={GATEWAYS.get(network)}")
 
+    params = prepare_params(params)
+
     if len(params) > 0:
         command.append("--inputs")
         command.extend(params)
